pub struct Input {
size: usize,
aa: usize,
all_valves: usize,
flow: Vec<u32>,
distance: Vec<u32>,
closest: Vec<u32>,
}Expand description
Simplified graph of valves. Valves are stored in descending order of flow so the valve at index 0 has the highest flow, valve at index 1 the second highest and so on. This descending order is used by the heuristic to prune branches.
sizeNumber of non-zero valves plus 1 forAAtodoBitmask with a1for each initial unopened non-zero valve. For example, if there are 5 valves this would be binary11111.flowStores the flow for each valvedistanceAdjacency matrix of distances between each pair of valves.
Fields
size: usizeaa: usizeall_valves: usizeflow: Vec<u32>distance: Vec<u32>closest: Vec<u32>Auto Trait Implementations
impl Freeze for Input
impl RefUnwindSafe for Input
impl Send for Input
impl Sync for Input
impl Unpin for Input
impl UnsafeUnpin for Input
impl UnwindSafe for Input