struct State {
todo: usize,
from: usize,
time: u32,
pressure: u32,
}Expand description
State of a single exploration path through the valves.
todoBinary mask of unopened valves. For example, if there are 3 unopened valves left this could look like11100.fromIndex of current valve.timeThe remaining time left.pressureTotal pressure released from all opened valves including future extrapolated flow.
Fields
todo: usizefrom: usizetime: u32pressure: u32Auto Trait Implementations
impl Freeze for State
impl RefUnwindSafe for State
impl Send for State
impl Sync for State
impl Unpin for State
impl UnsafeUnpin for State
impl UnwindSafe for State